# AUTOGENERATED! DO NOT EDIT! File to edit: dictUtil.ipynb (unless otherwise specified).

__all__ = ['printDict', 'allKeysInDict']

# Cell
def printDict(d:dict, length:int = 10, space = 0):
  '''print dictionary as first x value of values'''
  if type(d) != dict:
    print('this is not a dict')
    print(d)
  else:
    for k, v in d.items():
      if type(v) == dict:
        print(f"{' '*space}{k}")
        printDict(v, space=space+1)
      else:
        print(f"{' '*space}{k} : {v[:length] if type(v)==str else v}")

# Cell
def allKeysInDict(inputDict:dict, keys:list):
  return all(key in inputDict for key in keys)


# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"imageFromS3": "Images.ipynb",
         "imageFromUrl": "Images.ipynb",
         "imageToS3": "Images.ipynb",
         "resizeImage": "Images.ipynb",
         "showImgS3": "Images.ipynb",
         "printDict": "dictUtil.ipynb",
         "allKeysInDict": "dictUtil.ipynb",
         "errorString": "exception.ipynb",
         "getSecret": "secrets.ipynb",
         "shorten": "shortenLInk.ipynb",
         "url": "shortenLInk.ipynb",
         "add_method": "wrappers.ipynb"}

modules = ["images.py",
           "dictUtil.py",
           "exception.py",
           "secrets.py",
           "shortenLink.py",
           "wrappers.py"]

doc_url = "https://thanakijwanavit.github.io/nicHelper/"

git_url = "https://github.com/thanakijwanavit/nicHelper/tree/master/"

def custom_doc_links(name): return None
